//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Program        : Craps Statistics
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  University of California, Irvine
//                  Irvine, CA 92617-3435
//                  e-mail: pattis@ics.uci.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   Craps prompts the user to enter the number of games to play. It then
// plays (simulates) that many games of craps, keeping the win/loss
// information. At the end, it displays these statistics.
//
//   Craps is a dice game. The thrower loses if he/she immediately rolls a 2
// (snake eyes), 3, or 12 (box cars). The thrower wins if he/she immediately
// rolls a 7 or 11. If the thrower does not immediately win or lose, the number
// thrown becomes the "point". Afterwards, the thrower tries to make his/her
// point by rolling that same value again (and winning) before rolling a 7
// (and losing). When trying to make his/her point, the thrower keeps rolling
// if he/she rolls any number other than the point or 7.
//
// Known Bugs     : None
//
// Future Plans   : None
//
// Program History:
//   8/ 8/00: R. Pattis - Operational in C++
//   5/15/01: R. Pattis - Translated to Java
//   5/16/01: R. Pattis - Changed identifiers to conform to Java style
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////


import edu.uci.ics.pattis.introlib.Prompt;


public class Application {



	////////////////////////////////////////////////////////////
	////////////////////////////////////////////////////////////
	//
	//  Pre : howMany >= 1
	//  Post: Returns sum of howMany random values in the range 1-6
	//

	public static int throwDice (int howMany)
	{
	  int sum = 0;
	  for (int i=0; i<howMany; i++)
	    sum += Math.round(Math.random()*6. + .5);
	  return sum;
	}



	public static void main (String[] args)	{
	        
	  int game       = 0; 	                //Current game being played
	  int winCount   = 0;             	    //Win/Lose/Dice Statistics
	  int loseCount  = 0;
	  int diceThrown = 0;

	  int gamesToPlay = Prompt.forInt("Enter # of games to play");
	  
	  
	  //Play the required number of games according to the rules of
	  //craps (throwing two dice at a time, ultimately recording the
	  //win or loss
	  
	  for(;;) {															//Each loop iteration plays one game
	    game++;															//Start a new game

	    int roll = throwDice(2);            //Roll the first pair of dice in the game
	    diceThrown += 2;
	    
      //Based on Roll, decide how to continue
      if (roll == 7 || roll == 11)
      	winCount++;												//Win on the first roll with 7 or 11
      	
		  else if (roll == 2 || roll == 3 || roll == 12)
		    loseCount++;				              //Lose on the first roll with 2, 3, or 12

      else {
	      int point = roll;       					//Try to make the point as the game continues

        //Playout this point, terminating when the point is re-rolled
        //(a win) or a 7 is rolled (a loss)
        for (;;) {         								//Roll until roll Point (win) or 7 (lose)
          roll = throwDice(2);
          diceThrown += 2;
          if (roll == point) {						//If made the point
            winCount++;			  						//...win and this game is over
            break;
          }else if (roll == 7) {					//If roll a 7 first
            loseCount++;		  						//...lose and this game is over
            break; 
          }
        }
      }

	    //////////////////////////
	    if (game == gamesToPlay)            //Terminate main loop after requisite games played
	       break;
	    //////////////////////////
	  }



	  //Display Statistics
	  
	  System.out.println("  Raw Wins/Lose = " + winCount + "/" + loseCount);
	  System.out.println("  % Wins/Lose   = " + 100.0*winCount/(winCount+loseCount)
	                     + "/" + 100.0*loseCount/(winCount+loseCount));
	  System.out.println();

	  System.out.println("  Dice Thrown   = " + diceThrown);
	  System.out.println("  Avg Dice/game = " + (double)diceThrown/(double)gamesToPlay);
  }
  
}